==> nextcloud-app-bookmarks-1%3A13.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ko.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "북마크",
    "You bookmarked \"%s\"" : "\"%s\"을(를) 북마크에 추가함",
    "%1$s bookmarked \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 북마크에 추가함",
    "Someone bookmarked \"%s\"" : "누군가 \"%s\"을(를) 북마크에 추가함",
    "You deleted \"%s\"" : "\"%s\"을(를) 삭제함",
    "%1$s deleted \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 삭제함",
    "Someone deleted \"%s\"" : "누군가 \"%s\"을(를) 삭제함",
    "You created folder \"%s\"" : "폴더 \"%s\"을(를) 생성함",
    "%1$s created folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 생성함",
    "Someone created folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 생성함",
    "You moved folder \"%s\"" : "폴더 \"%s\"을 이동함",
    "%1$s moved folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 이동함",
    "Someone moved folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 이동함",
    "You deleted folder \"%s\"" : "폴더 \"%s\"을(를) 삭제함",
    "%1$s deleted folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 삭제함",
    "Someone deleted folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 삭제함",
    "You shared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"을(를) %2$s와(과) 공유함",
    "You shared folder \"%s\" with someone" : "폴더 \"%s\"을(를) 누군가와 공유함",
    "%1$s shared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"을(를) 공유함",
    "Someone shared folder \"%s\" with you" : "누군가 폴더 \"%s\"을(를) 공유함",
    "You unshared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"에 대한 %2$s와(과)의 공유를 해체함",
    "You unshared folder \"%s\" with someone" : "폴더 \"%s\"에 대한 누군가와의 공유를 해제함",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"에 대한 공유를 해제함",
    "Someone unshared folder \"%s\" with you" : "누군가 \"%s\"에 대한 공유를 해제함",
    "No file provided for import" : "가져올 파일을 지정하지 않았음",
    "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
    "Bookmarks Backups" : "북마크 백업",
    "Bookmarks shared by %s" : "%s님이 공유한 북마크 ",
    "Frequent bookmarks" : "자주 방문한 북마크",
    "Recent bookmarks" : "최근 북마크",
    "Bookmark" : "북마크",
    "Bookmark deleted" : "북마크가 삭제됨",
    "Bookmark created" : "북마크가 생성됨",
    "Bookmark moved" : "북마크가 이동함",
    "Bookmark updated" : "북마크가 갱신됨",
    "Create bookmark" : "북마크 생성",
    "Takes a link and adds it to your collection of bookmarks." : "링크를 북마크 목록에 추가하십시오.",
    "A Bookmark manager for Nextcloud" : "Nextcloud 북마크 관리자",
    "Select bookmark" : "북마크 선택",
    "Details" : "자세한 정보",
    "Rename" : "이름 바꾸기",
    "Copy link" : "링크 복사",
    "Move" : "이동",
    "Delete" : "삭제",
    "Link copied to clipboard" : "링크가 클립보드로 복사됨",
    "Select all" : "Select all",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
    "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
    "Go back" : "뒤로 가기",
    "Share folder" : "폴더 공유",
    "New" : "새로 만들기",
    "New bookmark" : "새로운 북마크",
    "New folder" : "새 폴더",
    "Search" : "검색",
    "Sort by created date" : "만들어진 순서로 정렬",
    "Enter a link" : "링크를 입력하시오.",
    "Add a bookmark" : "북마크 추가",
    "Select folder" : "폴더 선택",
    "Enter folder title" : "폴더명을 입력하시오.",
    "Shared by {user}" : "{user}가 공유한",
    "Rename folder" : "폴더 이름 바꾸기",
    "Delete folder" : "폴더 삭제",
    "Choose folder" : "폴더 선택",
    "Submit" : "제출",
    "Cancel" : "취소",
    "Recent" : "최근 항목",
    "Shared with you" : "나와 공유됨",
    "Files" : "파일",
    "Untagged" : "태그 지우기",
    "Import" : "가져오기",
    "Export" : "내보내기",
    "Bookmarklet" : "북마크릿",
    "Add to {instanceName}" : "{instanceName}에 더하기",
    "Title" : "직위",
    "Link" : "링크",
    "Root folder" : "루트 폴더",
    "Tags" : "태그",
    "Notes" : "Notes",
    "Download file" : "파일 다운로드",
    "Owner" : "Owner",
    "Sharing" : "공유",
    "Share link" : "링크 공유",
    "Delete link" : "링크 삭제",
    "Allow editing" : "Allow editing",
    "Allow resharing" : "재공유 허용",
    "Remove share" : "공유 삭제",
    "Link copied" : "링크 복사됨",
    "Privacy" : "프라이버시",
    "Performance" : "성능",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "계정 당 최대 북마크 수 (0을 입력할 시 무제한이며 이는 기본값입니다.)",
    "Previews" : "미리 보기",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API 키",
    "Failed to save settings" : "환경설정 저장 실패",
    "Failed to load settings" : "환경설정 로딩 실패",
    "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
    "Enter bookmark title" : "북마크 제목을 입력하시오.",
    "Enter bookmark URL" : "북마크 URL을 입력하시오.",
    "Folder" : "폴더",
    "Root Folder" : "최상위 폴더",
    "Save" : "저장",
    "Bookmarks feed" : "북마크 피드"
},
"nplurals=1; plural=0;");

==> nextcloud-app-bookmarks-1%3A14.2.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ko.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "북마크",
    "You bookmarked \"%s\"" : "\"%s\"을(를) 북마크에 추가함",
    "%1$s bookmarked \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 북마크에 추가함",
    "Someone bookmarked \"%s\"" : "누군가 \"%s\"을(를) 북마크에 추가함",
    "You deleted \"%s\"" : "\"%s\"을(를) 삭제함",
    "%1$s deleted \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 삭제함",
    "Someone deleted \"%s\"" : "누군가 \"%s\"을(를) 삭제함",
    "You created folder \"%s\"" : "폴더 \"%s\"을(를) 생성함",
    "%1$s created folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 생성함",
    "Someone created folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 생성함",
    "You moved folder \"%s\"" : "폴더 \"%s\"을 이동함",
    "%1$s moved folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 이동함",
    "Someone moved folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 이동함",
    "You deleted folder \"%s\"" : "폴더 \"%s\"을(를) 삭제함",
    "%1$s deleted folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 삭제함",
    "Someone deleted folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 삭제함",
    "You shared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"을(를) %2$s와(과) 공유함",
    "You shared folder \"%s\" with someone" : "폴더 \"%s\"을(를) 누군가와 공유함",
    "%1$s shared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"을(를) 공유함",
    "Someone shared folder \"%s\" with you" : "누군가 폴더 \"%s\"을(를) 공유함",
    "You unshared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"에 대한 %2$s와(과)의 공유를 해체함",
    "You unshared folder \"%s\" with someone" : "폴더 \"%s\"에 대한 누군가와의 공유를 해제함",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"에 대한 공유를 해제함",
    "Someone unshared folder \"%s\" with you" : "누군가 \"%s\"에 대한 공유를 해제함",
    "No file provided for import" : "가져올 파일을 지정하지 않았음",
    "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
    "Bookmarks shared by %s" : "%s님이 공유한 북마크 ",
    "Frequent bookmarks" : "자주 방문한 북마크",
    "Recent bookmarks" : "최근 북마크",
    "Bookmark" : "북마크",
    "Bookmark deleted" : "북마크가 삭제됨",
    "Bookmark created" : "북마크가 생성됨",
    "Bookmark moved" : "북마크가 이동함",
    "Bookmark updated" : "북마크가 갱신됨",
    "Create bookmark" : "북마크 생성",
    "Takes a link and adds it to your collection of bookmarks." : "링크를 북마크 목록에 추가하십시오.",
    "Bookmarks Backups" : "북마크 백업",
    "Select bookmark" : "북마크 선택",
    "Details" : "자세한 정보",
    "Rename" : "이름 바꾸기",
    "Copy link" : "링크 복사",
    "Move" : "이동",
    "Link copied to clipboard" : "링크가 클립보드로 복사됨",
    "Select all" : "Select all",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
    "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
    "Go back" : "뒤로 가기",
    "Share folder" : "폴더 공유",
    "New" : "새로 만들기",
    "New bookmark" : "새로운 북마크",
    "New folder" : "새 폴더",
    "Search" : "검색",
    "Sort by created date" : "만들어진 순서로 정렬",
    "Enter a link" : "링크를 입력하시오.",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "Add a bookmark" : "북마크 추가",
    "Select folder" : "폴더 선택",
    "Enter folder title" : "폴더명을 입력하시오.",
    "Shared by {user}" : "{user}가 공유한",
    "Rename folder" : "폴더 이름 바꾸기",
    "Choose folder" : "폴더 선택",
    "Submit" : "제출",
    "Cancel" : "취소",
    "Recent" : "최근 항목",
    "Shared with you" : "나와 공유됨",
    "Files" : "파일",
    "Delete" : "삭제",
    "Untagged" : "태그 지우기",
    "Settings" : "설정",
    "Bookmarklet" : "북마크릿",
    "Add to {instanceName}" : "{instanceName}에 더하기",
    "Need help?" : "도움이 필요한가요?",
    "Title" : "직위",
    "Link" : "링크",
    "Root folder" : "루트 폴더",
    "Tags" : "태그",
    "Notes" : "Notes",
    "Download file" : "파일 다운로드",
    "Owner" : "Owner",
    "Sharing" : "공유",
    "Share link" : "링크 공유",
    "Delete link" : "링크 삭제",
    "Editing allowed" : "수정 허용됨",
    "Allow editing" : "수정 허용",
    "Allow resharing" : "재공유 허용",
    "Remove share" : "공유 삭제",
    "Link copied" : "링크 복사됨",
    "Privacy" : "프라이버시",
    "Performance" : "성능",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "계정이 대량으로 존재할 경우 계정 당 최대 북마크 수를 제한하는 것이 좋습니다.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "계정 당 최대 북마크 수 (0을 입력할 시 무제한이며 이는 기본값입니다.)",
    "Previews" : "미리 보기",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API 키",
    "Failed to save settings" : "환경설정 저장 실패",
    "Failed to load settings" : "환경설정 로딩 실패",
    "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
    "Enter bookmark title" : "북마크 제목을 입력하시오.",
    "Enter bookmark URL" : "북마크 URL을 입력하시오.",
    "Folder" : "폴더",
    "Root Folder" : "최상위 폴더",
    "Save" : "저장",
    "What's new?" : "새로운 항목",
    "What" : "무엇을",
    "Failed to load tags" : "태그 불러오기 실패",
    "Bookmarks feed" : "북마크 피드"
},
"nplurals=1; plural=0;");
